@@ -1,6 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
-#include <bonobo/bonobo-main.h>
 #include <stdlib.h>
 #include <libebook/e-book.h>
 
@@ -75,9 +74,8 @@ main (int argc, char **argv)
 	EBook *book;
 	gboolean status;
 
-	if (bonobo_init (&argc, argv) == FALSE)
-		g_error ("Could not initialize Bonobo");
-
+	g_type_init ();
+	
 	/*
 	** the actual ebook foo
 	*/
