@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -63,19 +63,19 @@ parse_for_url (char *code, char *name, xmlNode *parent)
 {
 	xmlNode *child;
 	if (parent->type == XML_ELEMENT_NODE) {
-		if (strcmp (parent->name, "location") == 0) {
+		if (strcmp ((char*)parent->name, "location") == 0) {
 			child = parent->children;
 			g_assert (child->type == XML_TEXT_NODE);
-			if (strcmp (child->content, name) == 0) {
+			if (strcmp ((char*)child->content, name) == 0) {
 				xmlAttr *attr;
 				gchar *url = NULL;
 				for (attr = parent->properties; attr; attr = attr->next) {
-					if (strcmp (attr->name, "code") == 0) {
-						if (strcmp (attr->children->content, code) != 0)
+					if (strcmp ((char*)attr->name, "code") == 0) {
+						if (strcmp ((char*)attr->children->content, code) != 0)
 							return NULL;
 					}
-					if (strcmp (attr->name, "url") == 0)
-						url = attr->children->content;
+					if (strcmp ((char*)attr->name, "url") == 0)
+						url = (char*)attr->children->content;
 				}
 				return g_strdup (url);
 			}
