@@ -14,14 +14,16 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
 #ifndef _CAMEL_LIST_UTILS_H
 #define _CAMEL_LIST_UTILS_H
 
+G_BEGIN_DECLS
+
 /* This is a copy of Amiga's Exec lists, the head and tail nodes are
  * overlapped and merged into a single list header.  All operations
  * are O(1), including node removal and addition from/to either end of
@@ -123,4 +125,6 @@ CamelSListNode *camel_slist_remtail(CamelSList *l);
 int camel_slist_empty(CamelSList *l);
 int camel_slist_length(CamelSList *l);
 
+G_END_DECLS
+
 #endif
