@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -25,12 +25,13 @@
 #include <config.h>
 #endif
 
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <errno.h>
 #include <string.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
+#include <glib.h>
 #include <glib/gstdio.h>
 
 #include "camel-file-utils.h"
@@ -74,7 +75,7 @@ camel_stream_vfs_init (gpointer object, gpointer klass)
 {
 	CamelStreamVFS *stream = CAMEL_STREAM_VFS (object);
 
-	stream->handle = (gpointer) -1;
+	stream->handle = GINT_TO_POINTER (-1);
 	((CamelSeekableStream *)stream)->bound_end = CAMEL_STREAM_UNBOUND;
 }
 
@@ -83,7 +84,7 @@ camel_stream_vfs_finalize (CamelObject *object)
 {
 	CamelStreamVFS *stream_vfs = CAMEL_STREAM_VFS (object);
 
-	if (stream_vfs->handle != -1)
+	if (stream_vfs->handle != GINT_TO_POINTER (-1))
 		gnome_vfs_close (stream_vfs->handle);
 }
 
@@ -150,7 +151,7 @@ camel_stream_vfs_new_with_uri (const char *name, int flags, mode_t mode)
 {
 	GnomeVFSResult result;
 	GnomeVFSHandle *handle;
-	int vfs_flag;
+	int vfs_flag = 0;
 	
 	if (flags & O_WRONLY)
 		vfs_flag = vfs_flag | GNOME_VFS_OPEN_WRITE;
