@@ -5,18 +5,18 @@
  *  Copyright 1999-2003 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
+ *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -24,35 +24,37 @@
 #include <config.h>
 #endif
 
-#include <stdlib.h>
-#include <limits.h>
-#include <sys/types.h>
-#include <dirent.h>
-#include <sys/stat.h>
-#include <unistd.h>
 #include <errno.h>
-#include <string.h>
 #include <fcntl.h>
+#include <limits.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
-#ifndef _POSIX_PATH_MAX
+#include <glib.h>
+#include <glib/gi18n-lib.h>
+#include <glib/gstdio.h>
+
+#if !defined (G_OS_WIN32) && !defined (_POSIX_PATH_MAX)
 #include <posix1_lim.h>
 #endif
 
-#include "camel-local-folder.h"
-#include "camel-local-store.h"
-#include "camel-stream-fs.h"
-#include "camel-local-summary.h"
 #include "camel-data-wrapper.h"
-#include "camel-mime-message.h"
-#include "camel-stream-filter.h"
-#include "camel-mime-filter-from.h"
 #include "camel-exception.h"
-#include "camel-i18n.h"
-
-#include "camel-local-private.h"
-
+#include "camel-mime-filter-from.h"
+#include "camel-mime-message.h"
+#include "camel-private.h"
+#include "camel-stream-filter.h"
+#include "camel-stream-fs.h"
 #include "camel-text-index.h"
 
+#include "camel-local-folder.h"
+#include "camel-local-private.h"
+#include "camel-local-store.h"
+#include "camel-local-summary.h"
+
 #define d(x) /*(printf("%s(%d): ", __FILE__, __LINE__),(x))*/
 
 #ifndef PATH_MAX
@@ -204,21 +206,20 @@ camel_local_folder_construct(CamelLocalFolder *lf, CamelStore *parent_store, con
 {
 	CamelFolderInfo *fi;
 	CamelFolder *folder;
-	const char *root_dir_path, *name;
+	const char *root_dir_path;
+	char *name;
 	char *tmp, *statepath;
+#ifndef G_OS_WIN32
 	char folder_path[PATH_MAX];
 	struct stat st;
+#endif
 	int forceindex, len;
 	CamelURL *url;
 	CamelLocalStore *ls = (CamelLocalStore *)parent_store;
 	
 	folder = (CamelFolder *)lf;
 
-	name = strrchr(full_name, '/');
-	if (name)
-		name++;
-	else
-		name = full_name;
+	name = g_path_get_basename(full_name);
 
 	camel_folder_construct(folder, parent_store, full_name, name);
 
@@ -227,7 +228,7 @@ camel_local_folder_construct(CamelLocalFolder *lf, CamelStore *parent_store, con
 	len = strlen (root_dir_path);
 	tmp = g_alloca (len + 1);
 	strcpy (tmp, root_dir_path);
-	if (len>1 && tmp[len-1] == '/')
+	if (len>1 && G_IS_DIR_SEPARATOR(tmp[len-1]))
 		tmp[len-1] = 0;
 
 	lf->base_path = g_strdup(root_dir_path);
@@ -247,19 +248,19 @@ camel_local_folder_construct(CamelLocalFolder *lf, CamelStore *parent_store, con
 		camel_object_set(lf, NULL, CAMEL_LOCAL_FOLDER_INDEX_BODY, TRUE, 0);
 		camel_object_state_write(lf);
 	}
-
+#ifndef G_OS_WIN32
 	/* follow any symlinks to the mailbox */
 	if (lstat (lf->folder_path, &st) != -1 && S_ISLNK (st.st_mode) &&
 	    realpath (lf->folder_path, folder_path) != NULL) {
 		g_free (lf->folder_path);
 		lf->folder_path = g_strdup (folder_path);
 	}
-	
+#endif
 	lf->changes = camel_folder_change_info_new();
 
 	/* TODO: Remove the following line, it is a temporary workaround to remove
 	   the old-format 'ibex' files that might be lying around */
-	unlink(lf->index_path);
+	g_unlink(lf->index_path);
 
 	/* FIXME: Need to run indexing off of the setv method */
 
@@ -297,6 +298,7 @@ camel_local_folder_construct(CamelLocalFolder *lf, CamelStore *parent_store, con
 	/* we sync here so that any hard work setting up the folder isn't lost */
 	/*if (camel_local_summary_sync((CamelLocalSummary *)folder->summary, FALSE, lf->changes, ex) == -1) {
 		camel_object_unref (CAMEL_OBJECT (folder));
+		g_free(name);
 		return NULL;
 		}*/
 #endif
@@ -318,7 +320,7 @@ camel_local_folder_construct(CamelLocalFolder *lf, CamelStore *parent_store, con
 		camel_object_trigger_event(CAMEL_OBJECT (parent_store), "folder_created", fi);
 		camel_folder_info_free(fi);
 	}
-	
+	g_free(name);
 	return lf;
 }
 
