@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /* ExchangeHierarchyWebDAV: class for a normal WebDAV folder hierarchy
@@ -686,7 +686,9 @@ static const char *folder_props[] = {
 static const int n_folder_props = sizeof (folder_props) / sizeof (folder_props[0]);
 
 static const char *pub_folder_props[] = {
+	E2K_PR_EXCHANGE_FOLDER_CLASS,
 	E2K_PR_DAV_DISPLAY_NAME,
+	E2K_PR_EXCHANGE_PERMANENTURL,
 	E2K_PR_DAV_HAS_SUBS
 };
 static const int n_pub_folder_props = sizeof (pub_folder_props) / sizeof (pub_folder_props[0]);
@@ -788,7 +790,7 @@ scan_subtree (ExchangeHierarchy *hier, EFolder *parent, int mode)
 		subtrees = g_slist_remove (subtrees, folder);
 		/* Dont scan the subtree for deleteditems folder */
 		int_uri = e_folder_exchange_get_internal_uri (folder);
-		if (int_uri && !strcmp (int_uri, deleted_items_uri))
+		if (int_uri && deleted_items_uri && !strcmp (int_uri, deleted_items_uri))
 			continue;
 		scan_subtree (hier, folder, mode);
 	}
